var neoApp = angular.module('neo4jApp', ["neoServices"]);

neoApp.controller('StationsCtrl', function ($scope,StationService) {
	
	$scope.s = new sigma('canvas');
	$scope.selectedStation=null;
	
	// Initialisation de la liste des stations
	StationService.cypher({statements:[{statement:'MATCH (n:STATION) RETURN n.nom', resultDataContents:["row"]}]}).$promise
	.then(function (data){
		$scope.stations = data.results[0].data;
	});
	
	// Initialisation du graphe : recherche du noeud de depart 
	callInitGraph ();
	
	function callInitGraph ()
	{
		StationService.cypher({statements:[{statement:'MATCH (n:STATION {nom:"CHARPENNES"}) RETURN n', resultDataContents:["REST"]}]})
		.$promise
		.then(function (data){	
			
			$scope.s.graph.addNode(initGraph (data));			
			$scope.s.refresh ();
			});
	}
	
	$scope.searchPath = function() {
	      
		var cypherQueryPath = {statements:[{statement:"MATCH chemins=(depart:STATION{nom:{depart_param}})-[*]-(destination2:STATION{nom:{destination_param}})"							
			+" WITH nodes(chemins) AS Stations, relationships(chemins) AS Liens "
			+" RETURN Stations, Liens ", resultDataContents:["REST"],parameters:{"depart_param":"CHARPENNES","destination_param":$scope.selectedStation.row[0]}}]};
			 
	      StationService.cypher(cypherQueryPath)
			.$promise
			.then(function (e){ 				
				
				var resultLines = e.results[0].data;
				
				for (var j = 0 ; j < resultLines.length ; j++)
				{
					
					 var stationsColumn = resultLines[j].rest[0];
					 var liensColumn = resultLines[j].rest[1];
					 for (var i = 0 ; i < stationsColumn.length ; i++)
				     {					
						 try
						 {
							 var color = "#AAAAAA";
							 if (stationsColumn[i].data.nom == $scope.selectedStation)
							 {
								 color="#222222";
							 }
							var sigmaNode = neoNodetoSigmaNode (stationsColumn[i], color);
							$scope.s.graph.addNode(sigmaNode);
							
				    	  
						 }
						 catch (exception)
						 {
							 console.log(exception);
						 }
				     }
				 
				 	 for (var i = 0 ; i < liensColumn.length ; i++)
				     {					
						 neoRelToSigmaRel (liensColumn[i]);
				     }
				}			 
				
			     $scope.s.refresh ();
			     $scope.s.startForceAtlas2({outboundAttractionDistribution:true,edgeWeightInfluence:1,scalingRatio:2,adjustSizes:true});
			});
	};
	
	function neoNodetoSigmaNode (neoNode,color)
	{
		
		try {
			
			return	{
				id : neoNode.self,
				label : neoNode.data.nom,
				x : Math.random(),
				y : Math.random(),
				size : 3,
				all_relationships:neoNode.all_relationships,
				color:color,
				neonode:neoNode
			};
			
		} catch (e) {
			console.log(e);
		}
	}
	
	function initGraph (data)
	{
		
		try {
			
			console.log (data.results[0].data[0].rest[0]);
			var neoNode =data.results[0].data[0].rest[0];			
			return	neoNodetoSigmaNode (neoNode,"#222222");
			
		} catch (e) {
			console.log(e);
		}
	}
	
	function neoRelToSigmaRel (relation)
	{		
		var nodeFrom = relation.start;				
		var nodeTo = relation.end;			
		var ligne = relation.data.ligne;
		var edgeColor ="#000000";
		if (ligne == "A")
		{
			edgeColor ="#FF0000";
		}
		else if (ligne == "B")
		{
			edgeColor ="#0000FF";
		}
		else if (ligne == "D")
		{
			edgeColor ="#00FF00";
		}
		
		
		try {
			$scope.s.graph.addEdge({
					"id" : nodeFrom+"_"+nodeTo,
					"source" : nodeFrom,
					"target" : nodeTo,
					"color" : edgeColor
					
				});		
				
			} catch (e) {
				console.log(e);
			}
	}
	
	
});



